summaryrefslogtreecommitdiffstats
path: root/quanta/utility/quantacommon.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /quanta/utility/quantacommon.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'quanta/utility/quantacommon.h')
-rw-r--r--quanta/utility/quantacommon.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/quanta/utility/quantacommon.h b/quanta/utility/quantacommon.h
index 915de6fb..61c86f9e 100644
--- a/quanta/utility/quantacommon.h
+++ b/quanta/utility/quantacommon.h
@@ -48,7 +48,7 @@ public:
//Quanta main configuration structure
-class QConfig{
+class TQConfig{
public:
//Tag style options
uint tagCase;
@@ -137,12 +137,12 @@ quotation setting*/
static bool isKnownTag(const TQString& dtdName, const TQString& tag);
/** No descriptions */
static AttributeList* tagAttributes(const TQString& dtdName, const TQString& tag);
- /** Returns the QTag object for the tag "tag" from the DTD named "dtdname". */
- static QTag* tagFromDTD(const TQString& dtdName, const TQString& tag);
- /** Returns the QTag object for the tag "tag" from the DTD. */
- static QTag* tagFromDTD(const DTDStruct* dtd, const TQString& tag);
- /** Returns the QTag object for the node "node" from node's DTD. */
- static QTag* tagFromDTD(Node *node);
+ /** Returns the TQTag object for the tag "tag" from the DTD named "dtdname". */
+ static TQTag* tagFromDTD(const TQString& dtdName, const TQString& tag);
+ /** Returns the TQTag object for the tag "tag" from the DTD. */
+ static TQTag* tagFromDTD(const DTDStruct* dtd, const TQString& tag);
+ /** Returns the TQTag object for the node "node" from node's DTD. */
+ static TQTag* tagFromDTD(Node *node);
/** Returns an XML style string containing the GUI for attributes. */
static TQString xmlFromAttributes(AttributeList* attributes);
/** Returns 0 if the (line,col) is inside the area specified by the other arguments,